Module prelude

Module prelude 

Convenient imports for working with Boxy CLI.

This module re-exports all the essential types and functions that are commonly used when working with the boxy-cli library. Import this module to get everything you need at once.

Example

use boxy_cli::prelude::*;

let mut my_box = Boxy::new(BoxType::Double, "#00ffff");
my_box.add_text_sgmt("Hello, World!", "#ffffff", BoxAlign::Center);

Re-exports

pub use crate::boxer::*;

Macros

boxy
Macro for creating a new Boxy struct

Structs

BoxPad
Represents padding values for the text box in all four directions.

Enums

BoxAlign
Specifies the alignment of text within the text box or the box itself within the terminal.
BoxType
Defines the border style for the text box.